# django-graphql-admin

Don't want to use Relay with Graphene? Me either. All other packages for django implement the Relay interface :( 

graphene-django (todo: add link) adds the ability to filter and page but you must follow the Relay specs and that requires the use of Nodes, Edges, Connections, and Global ID's.

Apollo is a great GraphQL client and can still be used with Relay but can have it's down sites.
